@@ -135,28 +135,27 @@ try:
     conn = get_s3_conn()
     HAS_S3_TEST_ACCESS = True
     HAS_S3_MODEL_ACCESS = True
-except boto.exception.NoAuthHandlerFound as err:  # pragma: no cover
+except boto.exception.NoAuthHandlerFound:
     conn = None
-    logging.info("-> No connection to AWS, can't run remote tests.")
     HAS_S3_TEST_ACCESS = False
     HAS_S3_MODEL_ACCESS = False
+    logging.info("-> No s3 connection.")
+
 
 if HAS_S3_TEST_ACCESS:
     try:
         bucket = conn.get_bucket('spacer-test', validate=True)
-        HAS_S3_TEST_ACCESS = True
-    except boto.exception.S3ResponseError as err:  # pragma: no cover
+    except boto.exception.S3ResponseError:  # pragma: no cover
         logging.info("-> No connection to spacer-test bucket, "
-                     "can't run remote tests.")
+                     "can't run remote tests")
         HAS_S3_TEST_ACCESS = False
 
 if HAS_S3_MODEL_ACCESS:
     try:
         bucket = conn.get_bucket('spacer-tools', validate=True)
-        HAS_S3_MODEL_ACCESS = True
-    except boto.exception.S3ResponseError as err:  # pragma: no cover
+    except boto.exception.S3ResponseError:  # pragma: no cover
         logging.info("-> No connection to spacer-tools bucket, "
-                     "can't download models.")
+                     "can't download models")
         HAS_S3_MODEL_ACCESS = False
 
 # Add margin to avoid warnings when running unit-test.
